@@ -688,20 +688,16 @@ class WordToken(models.Model):
         if self.DialogPart == 'b' and self.Begin == 0.0:
             prev = WordToken.objects.filter(Dialog=self.Dialog).filter(DialogPart='a').order_by('-Begin')
         else:
-            prev = WordToken.objects.filter(Dialog=self.Dialog).filter(End__exact=self.Begin)
+            prev = WordToken.objects.filter(Dialog=self.Dialog).filter(pk=self.pk-1)
         if len(prev) > 0:
-            if len(prev) > 1 and prev[0].Category.CategoryType == 'Pause' and prev[0].getDuration() < 0.5:
-                return prev[1]
             return prev[0]
         return None
 
     def getFollowingWord(self):
-        foll = WordToken.objects.filter(Dialog=self.Dialog).filter(Begin__exact=self.End)
+        foll = WordToken.objects.filter(Dialog=self.Dialog).filter(pk=self.pk+1)
         if self.DialogPart == 'a' and len(foll) == 0:
             foll = WordToken.objects.filter(Dialog=self.Dialog).filter(DialogPart='b').filter(Begin__exact=0.0)
         if len(foll) > 0:
-            if len(foll) > 1 and foll[0].Category.CategoryType == 'Pause' and foll[0].getDuration() < 0.5:
-                return foll[1]
             return foll[0]
         return None
 
@@ -712,11 +708,10 @@ class WordToken(models.Model):
         while durSum <= window:
             if prev is None:
                 break
-            context.append(prev)
-            prev = prev.getPreviousWord()
-            if prev is None:
-                break
+            if prev.isWord():
+                context.append(prev)
             durSum += prev.getDuration()
+            prev = prev.getPreviousWord()
         return reversed(context)
 
     def getFollowingContext(self,window=10):
@@ -726,7 +721,8 @@ class WordToken(models.Model):
         while durSum <= window:
             if foll is None:
                 break
-            context.append(foll)
+            if foll.isWord():
+                context.append(foll)
             foll = foll.getFollowingWord()
             if foll is None:
                 break
